==> videorbits-2.201.tgz: videorbits-2.201/src/dst_to_src_pchirp2.c <==
#include <stdio.h>

/* dst_to_src....c                             Steve Mann, 1993 */
/* mapping for use by dechirp2.c, rechirp2.c, cement.f, ... */

/* global to this file */
static double in_vdim, in_hdim;
static double out_vdim, out_hdim;
static double a_inv,b_inv,c_inv,d_inv,e_inv,f_inv,g_inv,h_inv;

/* converts m1..n4 to p-chirplet parameters; returns nothing */
/* sets global variables for this file */
void dst_to_src_once_per_image(M_in,N_in,
                               M_out,N_out,
                               c1,c2,c3,c4,c5,c6,c7,c8) /* chirp parameters */
int M_in, N_in;
int M_out, N_out;
double c1,c2,c3,c4,c5,c6,c7,c8;
{
      in_vdim=(double)M_in;
      in_hdim=(double)N_in;
      out_vdim=(double)M_out;
      out_hdim=(double)N_out;

      /* pCHIRP CODE */

      a_inv = c1;  /* replaced 1500 lines or so with this identity map */
      b_inv = c2;
      c_inv = c3;
      d_inv = c4;
      e_inv = c5;
      f_inv = c6;
      g_inv = c7;
      h_inv = c8;

      /*  printf("++++++++++++++++++++++++++++++++++++++++++\n");  
  printf("a_inv: %6g  b_inv: %6g  c_inv: %6g  d_inv: %6g e_inv: %6g  f_inv: %6g  g_inv: %6g  h_inv: %6g\n", a_inv, b_inv, c_inv, d_inv, e_inv, f_inv, g_inv, h_inv);
  printf("++++++++++++++++++++++++++++++++++++++++++\n");
      */
}

/* takes destination pixel coordinates [m,n] and
   returns source sub-pixel coordinates [m_out, n_out] */
#ifdef __GNUC__
inline 
#endif

void new_dst_to_src_once_per_pixel(double x_in, double y_in, double * m_in, double * n_in) 
{
 /* dechirp, then deshear and translate back */
 /* (incomplete Lorentz transformations; replaced i with 1.0 ) */
 /* mapping from input vars (x_in,y_in) to input vars (x,y) */
  double denominator = (g_inv * y_in + h_inv * x_in + 1.0);
  double y_d = (a_inv * y_in + b_inv * x_in + c_inv) / denominator,
         x_d = (d_inv * y_in + e_inv * x_in + f_inv) / denominator;

  /*printf("-------------------------------------------\n");  
    printf("x_in: %6g  y_in: %6g\n", x_in, y_in);*/

  *m_in = y_d*in_vdim;
  *n_in = x_d*in_hdim;

  /*  printf("m_in: %6g  n_in: %6g\n", *m_in, *n_in);
      printf("-------------------------------------------\n");*/

}

/* takes destination pixel coordinates [m,n] and
   returns source sub-pixel coordinates [m_out, n_out] */
#ifdef __GNUC__
inline 
#endif


#ifndef HEADTRACKING
void dst_to_src_once_per_pixel(double m, double n, double * m_in, double * n_in)
{
  const double x_in = m / out_vdim,
               y_in = n / out_hdim,
               denominator = g_inv * x_in + h_inv * y_in + 1.0;
  double x_d = (a_inv * x_in + b_inv * y_in + c_inv) / denominator,
         y_d = (d_inv * x_in + e_inv * y_in + f_inv) / denominator;
  *m_in = x_d*in_vdim;
  *n_in = y_d*in_hdim;
}
#ifdef __GNUCC__
inline
#endif



void dst_to_src_once_per_pixel_noscaling(m,n,m_in,n_in)
double m,n,*m_in, *n_in;
{
  /* normalize input scan, x_in and y_in, to [0,1) */
  const double x_in = m / in_vdim,
               y_in= n / in_hdim,
               denominator = g_inv * x_in + h_inv * y_in + 1.0;

  /* if( DEBUG ) fprintf(stderr,"x_in=%f  y_in=%f\n",x_in,y_in); */
  /* incomplete Lorentz transformations; replaced i with 1.0 */
  /* mapping from input vars (x_in,y_in) to input vars (x,y) */
  double x_d = (a_inv*x_in + b_inv*y_in + c_inv) / denominator,
         y_d = (d_inv*x_in + e_inv*y_in + f_inv) / denominator;
  *m_in = (x_d*in_vdim);
  *n_in = (y_d*in_hdim);
}
#endif

==> videorbits-2.205.tgz: videorbits-2.205/src/dst_to_src_pchirp2.c <==
#include <stdio.h>

/* dst_to_src....c                             Steve Mann, 1993 */
/* mapping for use by dechirp2.c, rechirp2.c, cement.f, ... */

/* global to this file */
static double in_vdim, in_hdim;
static double out_vdim, out_hdim;
static double a_inv,b_inv,c_inv,d_inv,e_inv,f_inv,g_inv,h_inv;

/* converts m1..n4 to p-chirplet parameters; returns nothing */
/* sets global variables for this file */

void dst_to_src_once_per_image(
int M_in, int N_in,
int M_out, int N_out,
double c1,double c2,double c3,double c4,double c5,double c6,double c7, double c8)
{
      in_vdim=(double)M_in;
      in_hdim=(double)N_in;
      out_vdim=(double)M_out;
      out_hdim=(double)N_out;

      /* pCHIRP CODE */

      a_inv = c1;  /* replaced 1500 lines or so with this identity map */
      b_inv = c2;
      c_inv = c3;
      d_inv = c4;
      e_inv = c5;
      f_inv = c6;
      g_inv = c7;
      h_inv = c8;

      /*  printf("++++++++++++++++++++++++++++++++++++++++++\n");  
  printf("a_inv: %6g  b_inv: %6g  c_inv: %6g  d_inv: %6g e_inv: %6g  f_inv: %6g  g_inv: %6g  h_inv: %6g\n", a_inv, b_inv, c_inv, d_inv, e_inv, f_inv, g_inv, h_inv);
  printf("++++++++++++++++++++++++++++++++++++++++++\n");
      */
}

/* takes destination pixel coordinates [m,n] and
   returns source sub-pixel coordinates [m_out, n_out] */
//#ifdef __GNUC__
//inline 
//#endif
void new_dst_to_src_once_per_pixel(double x_in, double y_in, double * m_in, double * n_in) 
{
 /* dechirp, then deshear and translate back */
 /* (incomplete Lorentz transformations; replaced i with 1.0 ) */
 /* mapping from input vars (x_in,y_in) to input vars (x,y) */
  double denominator = (g_inv * y_in + h_inv * x_in + 1.0);
  double y_d = (a_inv * y_in + b_inv * x_in + c_inv) / denominator,
         x_d = (d_inv * y_in + e_inv * x_in + f_inv) / denominator;

  /*printf("-------------------------------------------\n");  
    printf("x_in: %6g  y_in: %6g\n", x_in, y_in);*/

  *m_in = y_d*in_vdim;
  *n_in = x_d*in_hdim;

  /*  printf("m_in: %6g  n_in: %6g\n", *m_in, *n_in);
      printf("-------------------------------------------\n");*/

}

/* takes destination pixel coordinates [m,n] and
   returns source sub-pixel coordinates [m_out, n_out] */
//#ifdef __GNUC__
//inline 
//#endif


#ifndef HEADTRACKING
void dst_to_src_once_per_pixel(double m, double n, double * m_in, double * n_in)
{
  const double x_in = m / out_vdim,
               y_in = n / out_hdim,
               denominator = g_inv * x_in + h_inv * y_in + 1.0;
  double x_d = (a_inv * x_in + b_inv * y_in + c_inv) / denominator,
         y_d = (d_inv * x_in + e_inv * y_in + f_inv) / denominator;
  *m_in = x_d*in_vdim;
  *n_in = y_d*in_hdim;
}
#ifdef __GNUCC__
inline
#endif



void dst_to_src_once_per_pixel_noscaling(
double m, double n, double *m_in,  double *n_in
		)
{
  /* normalize input scan, x_in and y_in, to [0,1) */
  const double x_in = m / in_vdim,
               y_in= n / in_hdim,
               denominator = g_inv * x_in + h_inv * y_in + 1.0;

  /* if( DEBUG ) fprintf(stderr,"x_in=%f  y_in=%f\n",x_in,y_in); */
  /* incomplete Lorentz transformations; replaced i with 1.0 */
  /* mapping from input vars (x_in,y_in) to input vars (x,y) */
  double x_d = (a_inv*x_in + b_inv*y_in + c_inv) / denominator,
         y_d = (d_inv*x_in + e_inv*y_in + f_inv) / denominator;
  *m_in = (x_d*in_vdim);
  *n_in = (y_d*in_hdim);
}
#endif
